# Python Documentation

This section contains documentation for Python code in the project.

## Files

* [src/thedoc/__init__.py](src_thedoc___init__.py.md)
* [src/thedoc/cli.py](src_thedoc_cli.py.md)
* [src/thedoc/config.py](src_thedoc_config.py.md)
* [src/thedoc/mkdocs_generator.py](src_thedoc_mkdocs_generator.py.md)
* [src/thedoc/parsers/__init__.py](src_thedoc_parsers___init__.py.md)
* [src/thedoc/parsers/base.py](src_thedoc_parsers_base.py.md)
* [src/thedoc/parsers/dotnet_parser.py](src_thedoc_parsers_dotnet_parser.py.md)
* [src/thedoc/parsers/kotlin_parser.py](src_thedoc_parsers_kotlin_parser.py.md)
* [src/thedoc/parsers/python.py](src_thedoc_parsers_python.py.md)
* [src/thedoc/parsers/swift_parser.py](src_thedoc_parsers_swift_parser.py.md)
* [tests/test_cli.py](tests_test_cli.py.md)
* [tests/test_dotnet_parser.py](tests_test_dotnet_parser.py.md)
* [tests/test_mkdocs_generator.py](tests_test_mkdocs_generator.py.md)
* [tests/test_python_parser.py](tests_test_python_parser.py.md)
* [tests/try_kotlin_parser.py](tests_try_kotlin_parser.py.md)
* [tests/try_parser.py](tests_try_parser.py.md)
* [tests/try_swift_parser.py](tests_try_swift_parser.py.md)
